@@ -47,7 +47,7 @@ SUB_TOOLS={
 TOOLS={
   "dl-model-tools":['dl-model-benchmark', 'nncf', 'omz-tools', 'openvino-dl-workbench','openvino-model-server', 
                     'openvino-training-extension', 'post-training-optimization-toolkit'],
-  "inference-runtimes":['intel-optimized-pytorch', 'intel-optimized-tensorflow','onxx', 'openvino-2022.1', 'openvino-addon-tensorflow'],
+  "inference-runtimes":['intel-optimized-pytorch', 'intel-optimized-tensorflow','onnx', 'openvino-2022.1', 'openvino-addon-tensorflow'],
   "model-zoo":['telemetry','analystics','perf-analysis','web-video-playback','rancher','OKD','tanzu'],
   "data-engineering-tools":['cvat'],
   "datasets":['emotion-recognition','face-detection','object-detection'],
